
/* Generated data (by glib-mkenums) */

#if !defined (__VTE_VTE_H_INSIDE__) && !defined (VTE_COMPILATION)
#error "Only <vte/vte.h> can be included directly."
#endif

#ifndef VTE_TYPE_BUILTINS_H
#define VTE_TYPE_BUILTINS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../../../src/vte.h" */
GType vte_terminal_erase_binding_get_type (void);
#define VTE_TYPE_TERMINAL_ERASE_BINDING (vte_terminal_erase_binding_get_type ())
GType vte_terminal_cursor_blink_mode_get_type (void);
#define VTE_TYPE_TERMINAL_CURSOR_BLINK_MODE (vte_terminal_cursor_blink_mode_get_type ())
GType vte_terminal_cursor_shape_get_type (void);
#define VTE_TYPE_TERMINAL_CURSOR_SHAPE (vte_terminal_cursor_shape_get_type ())
GType vte_terminal_write_flags_get_type (void);
#define VTE_TYPE_TERMINAL_WRITE_FLAGS (vte_terminal_write_flags_get_type ())

/* enumerations from "../../../src/vtepty.h" */
GType vte_pty_flags_get_type (void);
#define VTE_TYPE_PTY_FLAGS (vte_pty_flags_get_type ())
GType vte_pty_error_get_type (void);
#define VTE_TYPE_PTY_ERROR (vte_pty_error_get_type ())

/* enumerations from "../../../src/vtedeprecated.h" */
GType vte_terminal_anti_alias_get_type (void);
#define VTE_TYPE_TERMINAL_ANTI_ALIAS (vte_terminal_anti_alias_get_type ())
G_END_DECLS

#endif /* !VTE_TYPE_BUILTINS_H */

/* Generated data ends here */

